@@ -1,13 +1,9 @@
 #!/usr/bin/env python
 # coding: utf8
 
-"""
-Visual keyboard for pygame.
-
-Aims to be easy to use as highly customizable as well.
-"""
+"""Visual keyboard highly customizable for pygame."""
 
 from .vkeyboard import VKeyboardLayout, VKeyboard
 from .vrenderers import VKeyboardRenderer
 
-__version__ = '2.0.5'
+__version__ = '2.0.6'
