@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf8
 
-""" Simple keyboard usage using AZERTY layout. """
+"""Simple keyboard usage using QWERTY layout and input text."""
 
 # pylint: disable=import-error
 import pygame
@@ -29,12 +29,12 @@ def main(test=False):
 
     # Create keyboard
     layout = vkboard.VKeyboardLayout(vkboard.VKeyboardLayout.QWERTY)
-    keyboard = vkboard.VKeyboard(
-        screen,
-        on_key_event,
-        layout,
-        show_text_input=True)
-    keyboard.enable()
+    keyboard = vkboard.VKeyboard(screen,
+                                 on_key_event,
+                                 layout,
+                                 renderer=vkboard.VKeyboardRenderer.DARK,
+                                 show_text=True,
+                                 joystick_navigation=True)
 
     clock = pygame.time.Clock()
 
